@@ -1,27 +1,29 @@
 ######################################################################
 # create ONE comment
-# x is a string not a rich text string.  
 
 createCellComment <- function(cell, string,  
   author=NULL, visible=TRUE)
 {
   sheet <- .jcall(cell,
-    "Lorg/apache/poi/xssf/usermodel/XSSFSheet;", "getSheet")
+    "Lorg/apache/poi/ss/usermodel/Sheet;", "getSheet")
   wb <- .jcall(sheet,
-    "Lorg/apache/poi/xssf/usermodel/XSSFWorkbook;", "getWorkbook")
+    "Lorg/apache/poi/ss/usermodel/Workbook;", "getWorkbook")
 
   factory <- .jcall(wb,
-    "Lorg/apache/poi/xssf/usermodel/XSSFCreationHelper;", "getCreationHelper")
+    "Lorg/apache/poi/ss/usermodel/CreationHelper;", "getCreationHelper")
 
   anchor <- .jcall(factory,
     "Lorg/apache/poi/ss/usermodel/ClientAnchor;", "createClientAnchor")
   
   drawing <- .jcall(sheet,
-    "Lorg/apache/poi/xssf/usermodel/XSSFDrawing;", "createDrawingPatriarch")
+    "Lorg/apache/poi/ss/usermodel/Drawing;", "createDrawingPatriarch")
   
   comment <- .jcall(drawing,
     "Lorg/apache/poi/ss/usermodel/Comment;", "createCellComment", anchor)
-  .jcall(comment, "V", "setString", string)
+
+  rtstring <- factory$createRichTextString(string)  # rich text string
+ 
+  comment$setString(rtstring)
   if (!is.null(author))
     .jcall(comment, "V", "setAuthor", author)
   if (visible)
@@ -41,7 +43,7 @@ removeCellComment <- function(cell){
 
 getCellComment <- function(cell)
 {
-  comment <- .jcall(cell, "Lorg/apache/poi/xssf/usermodel/XSSFComment;",
+  comment <- .jcall(cell, "Lorg/apache/poi/ss/usermodel/Comment;",
     "getCellComment")
 
   comment
