@@ -1,6 +1,42 @@
-.onLoad <- function(libname, pkgname)
+# .guess_cell_type
+# .onLoad
+# .splitBlocks
+# .xssfcolor  
+
+
+
+###################################################################
+# given a vector of cells, return the "appropriate" R type
+# you cannot decide if it's a Date or a POSIXct
+#
+# only returns "numeric", "character", "POSIXct"
+#
+.guess_cell_type <- function(cells)
+{
+  browser()
+  cellType <- sapply(cells, function(x){x$getCellType()}) + 1
+
+  dateUtil   <- .jnew("org/apache/poi/ss/usermodel/DateUtil")
+  isDateTime <- mapply(function(x,y) {
+    if (y != 1) {  # if it's not numeric, forget about it
+      FALSE
+    } else {
+      dateUtil$isCellDateFormatted(x)
+    } 
+  }, cells, cellType)
+
+  guessedColClasses <- ifelse(cellType==1,"numeric", "character")
+
+  guessedColClasses[isDateTime] <- "POSIXct"
+  
+  guessedColClasses
+}
+
+
+####################################################################
+#
+.onAttach <- function(libname, pkgname)
 {
-  require(rJava)
   .jpackage(pkgname)  # needed to load RInterface.java
   
   # what's your java  version?  Need > 1.5.0.
@@ -8,11 +44,44 @@
   if (jversion < "1.5.0")
     stop(paste("Your java version is ", jversion,
                  ".  Need 1.5.0 or higher.", sep=""))
+  
+  wb <- createWorkbook()   # load/initialize jars here as it takes 
+  rm(wb)                   # a few seconds ...
+ }
 
-  #wb <- createWorkbook()   # load/initialize jars here as it takes 
-  #rm(wb)                   # a few seconds ...
+
+####################################################################
+#
+.onLoad <- function(libname, pkgname)
+{
+  #require(rJava)
+
+  
 }
 
+###################################################################
+# split a vector into contiguous chunks c(1,2,3, 6,7, 9,10,11)
+#
+.splitBlocks <- function(x)
+{
+  blocks <- list(x[1])
+  if (length(x)==1)
+    return(blocks)
+  
+  k <- 1
+  for (i in 2:length(x)) {
+    if (x[i]==(x[i-1]+1)) {
+      blocks[[k]] <- c(blocks[[k]], x[i])
+    } else {
+      k <- k+1
+      blocks[[k]] <- x[i]
+    }
+  }
+
+  blocks
+}
+
+
 ########################################################################
 # take an R color and return an XSSFColor object
 # where Rcolor is a string from "colors()"
@@ -23,28 +92,39 @@
   .jnew("org.apache.poi.xssf.usermodel.XSSFColor", jcol)
 }
 
-
-  .CELL_STYLES <- c(2,6,4,0,5,1,3,3,9,9,11,3,7,6,4,2,10,12,8,0,13,5,1,
-    10,16,2,18,17,0,1,4,15,7,8,5,6,13,14,11,12,2,1,3,0)
-  names(.CELL_STYLES) <- c('ALIGN_CENTER' ,'ALIGN_CENTER_SELECTION'
+  HALIGN_STYLES_ <- c(2,6,4,0,5,1,3)
+  names(HALIGN_STYLES_) <- c('ALIGN_CENTER' ,'ALIGN_CENTER_SELECTION'
     ,'ALIGN_FILL' ,'ALIGN_GENERAL' ,'ALIGN_JUSTIFY' ,'ALIGN_LEFT'
-    ,'ALIGN_RIGHT' ,'ALT_BARS' ,'BIG_SPOTS' ,'BORDER_DASH_DOT'
-    ,'BORDER_DASH_DOT_DOT1' ,'BORDER_DASHED' ,'BORDER_DOTTED'
-    ,'BORDER_DOUBLE' ,'BORDER_HAIR' ,'BORDER_MEDIUM'
-    ,'BORDER_MEDIUM_DASH_DOT1' ,'BORDER_MEDIUM_DASH_DOT_DOT1'
-    ,'BORDER_MEDIUM_DASHED' ,'BORDER_NONE' ,'BORDER_SLANTED_DASH_DOT1'
-    ,'BORDER_THICK' ,'BORDER_THIN' ,'BRICKS1' ,'DIAMONDS1'
-    ,'FINE_DOTS' ,'LEAST_DOTS1' ,'LESS_DOTS1' ,'NO_FILL'
-    ,'SOLID_FOREGROUND' ,'SPARSE_DOTS' ,'SQUARES1'
-    ,'THICK_BACKWARD_DIAG' ,'THICK_FORWARD_DIAG' ,'THICK_HORZ_BANDS'
-    ,'THICK_VERT_BANDS' ,'THIN_BACKWARD_DIAG1' ,'THIN_FORWARD_DIAG1'
-    ,'THIN_HORZ_BANDS1' ,'THIN_VERT_BANDS1' ,'VERTICAL_BOTTOM'
-    ,'VERTICAL_CENTER' ,'VERTICAL_JUSTIFY' ,'VERTICAL_TOP')
+    ,'ALIGN_RIGHT')
 
-  .INDEXED_COLORS <- c(8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,
+  VALIGN_STYLES_<- c(2,1,3,0)
+  names(VALIGN_STYLES_) <- c('VERTICAL_BOTTOM' ,'VERTICAL_CENTER',
+                             'VERTICAL_JUSTIFY' ,'VERTICAL_TOP')
+              
+  BORDER_STYLES_ <- c(9,11,3,7,6,4,2,10,12,8,0,13,5,1)
+  names(BORDER_STYLES_) <- c("BORDER_DASH_DOT", "BORDER_DASH_DOT_DOT",
+    "BORDER_DASHED", "BORDER_DOTTED", "BORDER_DOUBLE", "BORDER_HAIR",
+    "BORDER_MEDIUM", "BORDER_MEDIUM_DASH_DOT",
+    "BORDER_MEDIUM_DASH_DOT_DOT", "BORDER_MEDIUM_DASHED",
+    "BORDER_NONE", "BORDER_SLANTED_DASH_DOT", "BORDER_THICK",
+    "BORDER_THIN")
+
+  FILL_STYLES_<- c(3,9,10,16,2,18,17,0,1,4,15,7,8,5,6,13,14,11,12)
+  names(FILL_STYLES_) <- c('ALT_BARS', 'BIG_SPOTS','BRICKS' ,'DIAMONDS'
+    ,'FINE_DOTS' ,'LEAST_DOTS' ,'LESS_DOTS' ,'NO_FILL'
+    ,'SOLID_FOREGROUND' ,'SPARSE_DOTS' ,'SQUARES'
+    ,'THICK_BACKWARD_DIAG' ,'THICK_FORWARD_DIAG' ,'THICK_HORZ_BANDS'
+    ,'THICK_VERT_BANDS' ,'THIN_BACKWARD_DIAG' ,'THIN_FORWARD_DIAG'
+    ,'THIN_HORZ_BANDS' ,'THIN_VERT_BANDS')
+
+  # from org.apache.poi.ss.usermodel.CellStyle  
+  CELL_STYLES_ <- c(HALIGN_STYLES_, VALIGN_STYLES_,
+     BORDER_STYLES_, FILL_STYLES_)
+
+  INDEXED_COLORS_ <- c(8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,
     25,26,28,29,30,31,40,41,42,43,44,45,46,47,48,49,50,51,52,53,54,55,
     56,57,58,59,60,61,62,63,64)
-  names(.INDEXED_COLORS) <- c('BLACK' ,'WHITE' ,'RED' ,'BRIGHT_GREEN'
+  names(INDEXED_COLORS_) <- c('BLACK' ,'WHITE' ,'RED' ,'BRIGHT_GREEN'
     ,'BLUE' ,'YELLOW' ,'PINK' ,'TURQUOISE' ,'DARK_RED' ,'GREEN'
     ,'DARK_BLUE' ,'DARK_YELLOW' ,'VIOLET' ,'TEAL' ,'GREY_25_PERCENT'
     ,'GREY_50_PERCENT' ,'CORNFLOWER_BLUE' ,'MAROON' ,'LEMON_CHIFFON'
@@ -60,62 +140,12 @@
 
 
 
+# probably should use
+# .jfield("org.apache.poi.ss.usermodel.CellStyle", NULL, "ALIGN_CENTER") # 2
+## CELL_STYLES <- function(x) {
+## }
 
-
-## aux <- "
-## 	ALIGN_CENTER	2
-## 	ALIGN_CENTER_SELECTION	6
-## 	ALIGN_FILL	4
-## 	ALIGN_GENERAL	0
-## 	ALIGN_JUSTIFY	5
-## 	ALIGN_LEFT	1
-## 	ALIGN_RIGHT	3
-## 	ALT_BARS	3
-## 	BIG_SPOTS	9
-## 	BORDER_DASH_DOT	9
-## 	BORDER_DASH_DOT_DOT	11
-## 	BORDER_DASHED	3
-## 	BORDER_DOTTED	7
-## 	BORDER_DOUBLE	6
-## 	BORDER_HAIR	4
-## 	BORDER_MEDIUM	2
-## 	BORDER_MEDIUM_DASH_DOT	10
-## 	BORDER_MEDIUM_DASH_DOT_DOT	12
-## 	BORDER_MEDIUM_DASHED	8
-## 	BORDER_NONE	0
-## 	BORDER_SLANTED_DASH_DOT	13
-## 	BORDER_THICK	5
-## 	BORDER_THIN	1
-## 	BRICKS	10
-## 	DIAMONDS	16
-## 	FINE_DOTS	2
-## 	LEAST_DOTS	18
-## 	LESS_DOTS	17
-## 	NO_FILL	0
-## 	SOLID_FOREGROUND	1
-## 	SPARSE_DOTS	4
-## 	SQUARES	15
-## 	THICK_BACKWARD_DIAG	7
-## 	THICK_FORWARD_DIAG	8
-## 	THICK_HORZ_BANDS	5
-## 	THICK_VERT_BANDS	6
-## 	THIN_BACKWARD_DIAG	13
-## 	THIN_FORWARD_DIAG	14
-## 	THIN_HORZ_BANDS	11
-## 	THIN_VERT_BANDS	12
-## 	VERTICAL_BOTTOM	2
-## 	VERTICAL_CENTER	1
-## 	VERTICAL_JUSTIFY	3
-## 	VERTICAL_TOP	0"
-  
-## bux <- strsplit(aux, "\n")[[1]][-1]
-## fields <- paste(gsub("(.*)[[:digit:]]+", "\\1", bux), sep="",
-##   collapse="' ,'")
-## values <- paste(as.numeric(gsub("[[:upper:]]|_", "", bux)), sep="",
-##                 collapse=",")
-
-## gsub(".*([[:digit:]]+)$", "\\1", bux, perl=TRUE)
-
+ 
 
 
 ##   aux <- 
